const path = require("path");

/**
 * Configuration object for linting and reporting.
 * @property {string} ruleConfigurationPath - The path to the ESLint configuration file.
 * @property {boolean} impactBased - Indicates if the linting is impact-based.
 * @property {string} lintReportPath - The path to the lint report JSON file.
 * @property {string} metricServerHost - The URL of the SonarQube server.
 * @property {string} meticHandler_api_token -  The token for authentication with the SonarQube server.
 * @property {string} metric_token - The token for authentication with the SonarQube server.
 * @property {string} gitEndPoint - API EndPoint for Git Actions
 * @property {string} tsConfigurationPath - The path of the ts configuration Path
 * @property {number} projectId - project id of repository
 * @property {boolean} impactBasedPrecommit - Indicates if the linting is impact-based in pre commit
 * @property {boolean} shouldWarningsAbortCommit - Indicates if eslint warnings should abort the commit
 * @property {string} pushMetricsOnPreCommit -  Indicates to push metrics to sonarQube or not
 * @property {string} token - Encrypted Authentication Token
 * @property {string} compareBranch - Branch to compare diff
 */


module.exports = {
  ruleConfigurationPath: path.resolve(process.cwd(), ".eslintrc.js"),
  impactBased: true,
  lintReportPath: path.resolve(process.cwd(), "lint-report", "lintReport.json"),
  metricServerHost: "https://client-linters.zohodesk.csez.zohocorpin.com",
  meticHandler_api_token:"",
  metric_token: "",
  branchDiffPath:path.resolve(process.cwd(),"diffBranch.json"),
  gitEndPoint:"https://zgit.csez.zohocorpin.com",
  tsConfigurationPath:path.resolve(process.cwd(),'tsconfig.json'),
  projectId:`project-id`,
  impactBasedPrecommit:true,
  shouldWarningsAbortCommit: false,
  pushMetricsOnPreCommit:true,
  token:"",
  compareBranch:'release'
};

